Module sampler

Module sampler 

Structs

BatchModelResult
Lightweight result for a single model in a batch run (1 chain).
SampleResult
SamplerConfig

Enums

SamplerType

Functions

batch_sample
Run many independent models in parallel through one Rayon thread pool.
sample