Module sampler
rustmc_
core
0.6.0
Module sampler
Module Items
Structs
Enums
Functions
In crate rustmc_
core
rustmc_core
Module
sampler
Structs

Batch
Model
Result
Lightweight result for a single model in a batch run (1 chain).
Sample
Result
Sampler
Config
Enums

Sampler
Type
Functions

batch_
sample
Run many independent models in parallel through one Rayon thread pool.
sample